@@ -324,8 +324,8 @@ namespace lsvpd
 		unsigned dlen;
 
 		ptr = buf;
-		memcpy(&size, ptr, 4);
-		ptr += 4;
+		size = be32toh(*(u32 *)ptr);
+		ptr += sizeof(u32);
 		dataEnd = ptr + size;
 
 		type = *(ptr++);
@@ -800,10 +800,10 @@ ERROR:
 		{
 			Logger logger;
 			logger.log( interp_err_code(bufSize), LOG_WARNING );
-			return;
+		} else {
+			parseRtasVpd(devs, rtasData, bufSize);
+			delete rtasData;
 		}
-		parseRtasVpd(devs, rtasData, bufSize);
-		delete rtasData;
 
 		/* Grab System parameters, N5 & N6 */
 		getRtasSystemParams( devs );
